==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosPatchBodyActionFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosPatchBodyActionFluentImpl<A extends PodHttpChaosPatchBodyActionFluent<A>> extends BaseFluent<A> implements PodHttpChaosPatchBodyActionFluent<A>{
  public PodHttpChaosPatchBodyActionFluentImpl() {
  }
  public PodHttpChaosPatchBodyActionFluentImpl(PodHttpChaosPatchBodyAction instance) {
    this.withType(instance.getType()); 
    this.withValue(instance.getValue()); 
  }
  private String type;
  private String value;
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodHttpChaosPatchBodyActionFluentImpl that = (PodHttpChaosPatchBodyActionFluentImpl) o;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(type,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosPatchBodyActionFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosPatchBodyActionFluentImpl<A extends PodHttpChaosPatchBodyActionFluent<A>> extends BaseFluent<A> implements PodHttpChaosPatchBodyActionFluent<A>{
  public PodHttpChaosPatchBodyActionFluentImpl() {
  }
  public PodHttpChaosPatchBodyActionFluentImpl(PodHttpChaosPatchBodyAction instance) {
    if (instance != null) {
      this.withType(instance.getType());
      this.withValue(instance.getValue());
    }
  }
  private String type;
  private String value;
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosPatchBodyActionFluentImpl that = (PodHttpChaosPatchBodyActionFluentImpl) o;
    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(type,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}
